@@ -7,7 +7,8 @@
 #  Authors: Mike Orlov <m.orlov@abm-jsc.ru>
 import asyncio
 import sys
-import traceback
+import tempfile
+from pathlib import Path
 
 from run_markdown import get_logic_block_from_md_file
 
@@ -24,7 +25,8 @@ async def main():
             raise ValueError(f'Failed to convert {timeout_str!r} to float timeout') from None
     block = get_logic_block_from_md_file(target_file)
     try:
-        await block.evaluate(timeout=timeout)
+        with tempfile.TemporaryDirectory() as tmp_dir_name:
+            await block.evaluate(tmp_dir=Path(tmp_dir_name), timeout=timeout)
     except Exception as e:
         print("CHECK FAILED")
         print(repr(e))
