@@ -19,7 +19,7 @@ class ComparisonBuffer:
         print(self.to_str(depth))
 
     @property
-    def exception(self) -> Exception | None:
+    def exception(self) -> ExceptionGroup | None:
         exceptions = []
         for val in self.values:
             if (exc := val.exception) is not None:
@@ -27,5 +27,15 @@ class ComparisonBuffer:
         if exceptions:
             return ExceptionGroup('', exceptions)
 
+    @property
+    def exceptions_amount(self) -> int:
+        amount = 0
+        for val in self.values:
+            if isinstance(val, ComparisonBuffer):
+                amount += val.exceptions_amount
+            elif val.exception is not None:
+                amount += 1
+        return amount
+
     def append(self, value: 'ComparisonBuffer | Comparison | Exception') -> None:
         self.values.append(value)
