@@ -7,11 +7,13 @@
 #  Authors: Mike Orlov <m.orlov@abm-jsc.ru>
 import asyncio
 import shlex
-import traceback
+
 from dataclasses import dataclass, field
+from pathlib import Path
 from typing import Literal, Any
 
 import mistune
+import mistune.directives
 
 from run_markdown.json_comparator import JsonComparator
 from run_markdown.text_comparator import TextComparator
@@ -23,7 +25,7 @@ class RunResult:
     process: asyncio.subprocess.Process | None = None
 
 
-async def execute_code_block(code: str, language: str, timeout: float = 1) -> RunResult:
+async def execute_code_block(code: str, language: str, path: Path, timeout: float = 1) -> RunResult:
     if language == 'python':
         # process_args = ['script', '-q', '-c', 'python', '-c', code]
         process_args = ['script', '-q', '-c', f"python -c {shlex.quote(code)}"]
@@ -34,8 +36,8 @@ async def execute_code_block(code: str, language: str, timeout: float = 1) -> Ru
         raise ValueError('Unknown language')
 
     process: asyncio.subprocess.Process = await asyncio.create_subprocess_exec(
-        *process_args, stdout=asyncio.subprocess.PIPE, stdin=asyncio.subprocess.PIPE,
-        stderr=asyncio.subprocess.PIPE)
+        *process_args, cwd=str(path),
+        stdout=asyncio.subprocess.PIPE, stdin=asyncio.subprocess.PIPE, stderr=asyncio.subprocess.PIPE)
 
     result = RunResult()
     try:
@@ -89,7 +91,7 @@ async def terminate_running_processes(running_processes: list[asyncio.subprocess
                 await asyncio.wait_for(process.wait(), timeout=1)
             except asyncio.TimeoutError:
                 process.kill()
-        except ProcessLookupError as e:
+        except ProcessLookupError:
             pass
 
 
@@ -106,10 +108,14 @@ class Check:
     language: str
     expected_format: Literal['text', 'json'] | None = None
     expected: str | None = None
+    path: str | None = None
 
-    async def evaluate(self, depth: int = 0, timeout: float = 1) -> RunResult:
+    async def evaluate(self, tmp_dir: Path, depth: int = 0, timeout: float = 1) -> RunResult:
         print(' ' * depth + f"Run {self.language} code: {preview(self.code)}")
-        return await execute_code_block(self.code, language=self.language, timeout=timeout)
+        if self.path:
+            target_path = tmp_dir / self.path.removeprefix("/")
+            target_path.write_text(self.code)
+        return await execute_code_block(self.code, path=tmp_dir, language=self.language, timeout=timeout)
 
     def check_result(self, result: RunResult, depth: int = 0) -> None:
         if result.process is not None:
@@ -136,7 +142,6 @@ class Check:
             print('IGNORE')
 
 
-
 @dataclass
 class LogicBlock:
     name: str
@@ -149,18 +154,17 @@ class LogicBlock:
     def add(self, block: 'Check | LogicBlock') -> None:
         self.content.append(block)
 
-    async def evaluate(self, depth: int = 0, timeout: float = 1) -> None:
+    async def evaluate(self, tmp_dir: Path, depth: int = 0, timeout: float = 1) -> None:
         print(' ' * depth + f"Starting logic block {self.name!r}")
         running_processes = []
         try:
             for block in self.content:
-                result = await block.evaluate(depth + 1, timeout=timeout)
+                result = await block.evaluate(tmp_dir=tmp_dir, depth=depth + 1, timeout=timeout)
                 if result is not None:
                     if result.process is not None:
                         running_processes.append(result.process)
                     assert isinstance(block, Check)
                     block.check_result(result, depth + 1)
-
         finally:
             await terminate_running_processes(running_processes, depth)
 
@@ -169,7 +173,7 @@ def get_logic_block_from_md_file(file_path: str) -> LogicBlock:
     with open(file_path, 'r', encoding='utf-8') as f:
         text = f.read()
 
-    markdown = mistune.create_markdown()
+    markdown = mistune.create_markdown(plugins=[mistune.directives.FencedDirective([mistune.directives.Admonition()])])
     html, parse_state = markdown.parse(text)
     html: str
     parse_state: mistune.BlockState
@@ -177,14 +181,24 @@ def get_logic_block_from_md_file(file_path: str) -> LogicBlock:
     return parse_tokens_as_logic(parse_state.tokens, file_path)
 
 
+FILE_PATH_PREFIX = 'file://'
+FILE_PATH_POSTFIX = ':'
+
+
 def parse_tokens_as_logic(tokens: list[dict], root_name: str) -> LogicBlock:
     root = current_block = LogicBlock(name=root_name)
     last_check = None
+    path = None
     for token in tokens:
+        if token['type'] == 'paragraph' and (last_child := token.get('children', [])[-1])['type'] == 'strong':
+            if len(children := last_child.get('children', [])) == 1 and (sub_child := children[0])['type'] == 'text':
+                if (text := sub_child['raw']).startswith(FILE_PATH_PREFIX) and text.endswith(FILE_PATH_POSTFIX):
+                    path = text.removeprefix(FILE_PATH_PREFIX).removesuffix(FILE_PATH_POSTFIX)
         if token['type'] == 'block_code':
             language: str | None = token.get('attrs', {}).get('info', None)
             if language in ('python', 'shell', 'bash', 'sh'):
-                last_check = Check(code=token['raw'], language=language)
+                last_check = Check(code=token['raw'], language=language, path=path)
+                path = None
                 current_block.add(last_check)
             else:
                 if last_check is not None:
@@ -205,4 +219,3 @@ def parse_tokens_as_logic(tokens: list[dict], root_name: str) -> LogicBlock:
             target_parent.add(current_block := LogicBlock(block_name))
 
     return root
-
